@@ -5,6 +5,7 @@ package Apache::SWIT::HTPage;
 use base 'Apache::SWIT';
 use HTML::Tested;
 use Apache::SWIT::DB::Connection;
+use Data::Dumper;
 
 sub ht_root_class { return shift() . '::Root'; }
 
@@ -37,6 +38,9 @@ sub ht_swit_transactional_update {
 sub swit_update {
 	my ($class, $r) = @_;
 	my $tested = $class->ht_root_class->ht_convert_request_to_tree($r);
+	my @val_errs = $tested->ht_validate;
+	die "ht_validate failed on " . Dumper($tested)
+		. "with errors: " . Dumper(\@val_errs) if (@val_errs);
 	return $class->ht_swit_transactional_update($r, $tested);
 }
 
